/*
 * (C) Copyright 2006-2011 Nuxeo SA (http://nuxeo.com/) and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Contributors:
 *     Thierry Delprat
 */
package org.nuxeo.ecm.core.api;

/**
 * Exception that can be handled at UI level to display a dedicated user message
 *
 * @since 5.6
 */
public class RecoverableClientException extends NuxeoException {

    private static final long serialVersionUID = 1L;

    protected final String localizedMessage;

    protected final String[] params;

    public enum Severity {
        WARN, ERROR, FATAL
    };

    protected Severity severity = Severity.ERROR;

    public RecoverableClientException(String message, String localizedMessage, String[] params) {
        super(message);
        this.localizedMessage = localizedMessage;
        this.params = params;
    }

    public RecoverableClientException(String message, String localizedMessage, String[] params, Throwable cause) {
        super(message, cause);
        this.localizedMessage = localizedMessage;
        this.params = params;
    }

    @Override
    public String getLocalizedMessage() {
        return localizedMessage;
    }

    public String[] geLocalizedMessageParams() {
        return params;
    }

    public Severity getSeverity() {
        return severity;
    }

    public void setSeverity(Severity severity) {
        this.severity = severity;
    }
}
