/*
 * (C) Copyright 2012 Nuxeo SA (http://nuxeo.com/) and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Contributors:
 *     Andrei Nechaev
 */
package org.nuxeo.ecm.csv.core.operation;

import org.nuxeo.ecm.automation.core.Constants;
import org.nuxeo.ecm.automation.core.annotations.Context;
import org.nuxeo.ecm.automation.core.annotations.Operation;
import org.nuxeo.ecm.automation.core.annotations.OperationMethod;
import org.nuxeo.ecm.automation.core.annotations.Param;
import org.nuxeo.ecm.core.api.Blob;
import org.nuxeo.ecm.core.api.CoreSession;
import org.nuxeo.ecm.csv.core.CSVImporter;
import org.nuxeo.ecm.csv.core.CSVImporterOptions;
import org.nuxeo.ecm.csv.core.CSVImporterOptions.ImportMode;
import org.nuxeo.runtime.api.Framework;

@Operation(
        id = CSVImportOperation.ID,
        category = Constants.CAT_DOCUMENT,
        label = "Import"
)
public class CSVImportOperation {
    public static final String ID = "CSV.Import";

    @Context
    protected CoreSession mSession;

    @Param(name = "path")
    protected String mPath;

    @Param(name = "sendReport", required = false)
    protected boolean mSendReport;

    @Param(name = "documentMode", required = false)
    protected boolean mDocumentMode;

    @OperationMethod
    public String importCSV(Blob blob) {
        ImportMode importMode = mDocumentMode ? ImportMode.IMPORT : ImportMode.CREATE;
        CSVImporterOptions options = new CSVImporterOptions.Builder().sendEmail(mSendReport)
                                                                     .importMode(importMode)
                                                                     .build();

        CSVImporter csvImporter = Framework.getService(CSVImporter.class);
        return csvImporter.launchImport(mSession, mPath, blob.getFile(), blob.getFilename(), options);
    }

    @OperationMethod
    public String getStatus(String importID) {
        if (importID == null || importID.isEmpty()) {
            return null;
        }
        CSVImporter csvImporter = Framework.getService(CSVImporter.class);
        return csvImporter.getImportStatus(importID).toString();
    }
}
